The COD_LOCAL_COMPRA (site of acquisition) appers in the file
'Descricoes dos registros POF 2008-2009.doc' (documentation provided
by IBGE) as having the level 88801 associated to the label
ignorado, but in the files 'Classificacoes POF 2008-2009.doc' and
'Cadastro de local de aquisicoes da POF 2008-2009.xls' appears the
same label associated to other level, 99902. In the file
'Descricoes dos registros POF 2008-2009.doc' the level ZERO is
associated to the label nao aplicavel.
The variable COD_CARACTERISTICA (characteristic of the drugs)
has the value ZERO, when reading the data file, but that value is not
related to any category in any of the documentation files (provided by
IBGE).Because of that appears NAs in the categorical variables when
you read the data using the rotulos parameter of the
le.pesquisa function.