Learn R Programming

dicionariosIBGE (version 1.5)

dic16pof2008.2009: Dictionary for food consumption record POF 2008-2009 survey

Description

Data dictionary for reading "T_CONSUMO_S.txt" file (food consumption (type 16) record from POF 2008-2009 survey).

The COD_PREPARACAO (code for way of preparation) appers in the file 'Descricoes dos registros POF 2008-2009.doc' (documentation provided by IBGE) as having the level 99 associated to the label nao aplicavel, but in the file 'Classificacoes POF 2008-2009.doc' appears the same label associated to other level, 16. We choose the level 99, because it's the one that appears when reading the data file.

Arguments

encoding

UTF-8

format

This dictionary is a data frame with one line for each variable, and it has 4 columms, with important information of each variable. lll{ inicio numeric Position of the value's first character in the data file cod character Variable code tamanho numeric Field size desc character Short description }

source

The dictionaries were made based on the documentation of the PNAD survey available at http://www.ibge.gov.br.