Learn R Programming

dicionariosIBGE (version 1.5)

dic5pof2008.2009: Dictionary for inventory of durable goods record POF 2008-2009 survey

Description

Data dictionary for reading "T_INVENTARIO_S.txt" file (inventory of durable goods (type 5) record from POF 2008-2009 survey).

Arguments

encoding

UTF-8

format

This dictionary is a data frame with one line for each variable, and it has 4 columms, with important information of each variable. lll{ inicio numeric Position of the value's first character in the data file cod character Variable code tamanho numeric Field size desc character Short description }

source

The dictionaries were made based on the documentation of the PNAD survey available at http://www.ibge.gov.br.