Learn R Programming

dicionariosIBGE (version 1.5)

dic7pof2008.2009: Dictionary for outgoing 12 months record POF 2008-2009 survey

Description

Data dictionary for reading "T_DESPESA_12MESES_S.txt" file (outgoing 12 months (type 7) record from POF 2008-2009 survey).

The COD_LOCAL_COMPRA (site of acquisition) appers in the file 'Descricoes dos registros POF 2008-2009.doc' (documentation provided by IBGE) as having the level 88801 associated to the label ignorado, but in the files 'Classificacoes POF 2008-2009.doc' and 'Cadastro de local de aquisicoes da POF 2008-2009.xls' appears the same label associated to other level, 99902. In the file 'Descricoes dos registros POF 2008-2009.doc' the level ZERO is associated to the label nao aplicavel.

Arguments

encoding

UTF-8

format

This dictionary is a data frame with one line for each variable, and it has 4 columms, with important information of each variable. lll{ inicio numeric Position of the value's first character in the data file cod character Variable code tamanho numeric Field size desc character Short description }

source

The dictionaries were made based on the documentation of the PNAD survey available at http://www.ibge.gov.br.