Learn R Programming

dicionariosIBGE (version 1.5)

dicPME: Data Dictionaries for PME

Description

A data dictionary for the survey PME from 2002 to 2009.

Arguments

encoding

UTF-8

format

The dictionary is a data frame with one line for each survey variable, and it has the following columns:

lll{ inicio numeric Position of the value's first character in the data file cod character Variable code tamanho numeric Field size desc character Short description }

source

PME documentation available in the CD's made by IBGE