The two data.frames, dicdom2006 and dicpes2006, are data dictionaries used by the fuction le.pesquisa for reading the two microdada files provided by IBGE.
The two data.frames, dicdom2006supl and dicpes2006supl, are data dictionaries used by the fuction le.pesquisa for reading the two microdada files from the reconsidered survey provided by IBGE. If you want to see all the variables used in the survey use these dictionaries.