The two data.frames, dicdom2009 and dicpes2009, are data dictionaries used by the fuction le.pesquisa for reading the two microdada files provided by IBGE.
The two data.frames, rotdom2009 and rotpes2009, are labels of some data values. They are needed only if one wants to work with factors.