dicPOF: Data Dictionaries for POF
Description
One data dictionary for each record type from POF surveys of
1987/1988, 1995/1996, 2002/2003 and 2008/2009.encoding
UTF-8format
Each dictionary is a data frame with one line for each survey variable,
and it has the following columns:
lll{
inicio numeric Position of the value's first character in
the data file
cod character Variable code
tamanho numeric Field size
desc character Short description
}source
POF documentation available in the CD made by IBGE