In the column desc (dictionaries data frames) of all records we choose
to remove all accents to avoid encoding problems.
In the column rotulo (dictionaries label data frames) of all
records we choose to remove all accents to avoid encoding problems.
In this survey we didn't use the variable COD_ITEM (CÓDIGO DO
ITEM) in any of the type records that it appears, execpt in the food
consumption (type 16) record that COD_ITEM (CÓDIGO DO TIPO DE
ALIMENTO) is represented by another classification. That variable is
showed in the data frame produtos.
Dictionaries: