Learn R Programming

dicionariosIBGE (version 1.5)

dicdom2007: Data Dictionary for domiciles record PNAD 2007 survey

Description

Data dictionary for reading "DOM2007.TXT" file (domiciles record from PNAD 2007 survey). In the column desc we choose to remove all accents to avoid encoding problems.

Arguments

encoding

UTF-8

format

This dictionary is a data frame with one line for each survey variable, and it has 4 columms, with important information of each variable. lll{ inicio numeric Position of the value's first character in the data file cod character Variable code tamanho numeric Field size desc character Short description }

source

The dictionaries were made based on the documentation of the PNAD survey available at http://www.ibge.gov.br.