Learn R Programming

dicionariosIBGE (version 1.5)

dicionariosIBGE-package: Dictionaries for reading survey microdata from IBGE

Description

This package contains dictionaries for reading the following IBGE surveys: PNAD(1983, 1988, 1993-2007), PME(2002-2009) and POF(1987/1988, 1995/1996, 2002/2003, 2008/2009). The data can be read using the function le.pesquisa from package IBGEPesq.

Arguments

encoding

UTF-8

Details

ll{ Package: dicionariosIBGE Type: Package Version: 1.1 Date: 2010-05-14 License: GNU Public Licence LazyLoad: yes }

References

Surveys PNAD, PME and POF from IBGE

Examples

Run this code
## show all available dictionaries in the package
data(package = "dicionariosIBGE")

## load dictionaries for PNAD 1993
data(dicPNAD1993)
ls()

Run the code above in your browser using DataLab