Learn R Programming

dicionariosIBGE (version 1.5)

rot2pof2008.2009: Data Dictionary label for people record POF 2008-2009 survey

Description

One data dictionary label for reading "T_MORADOR_S.txt" file (people (type 2) record from POF 2008-2009 survey).

Arguments

encoding

UTF-8

format

This dictionary is a data frame with one line for each survey categorical variable, and it has 3 columms, with important information of each categorical variable. lll{ cod character Variable code valor numeric Levels of the categorical variable rotulo numeric Labels of the categorical variable }

source

The dictionaries were made based on the documentation of the PNAD survey available at http://www.ibge.gov.br.