Learn R Programming

dicionariosIBGE (version 1.5)

rot6pof2008.2009: Data Dictionary label for outgoing 90 days record POF 2008-2009 survey

Description

One data dictionary label for reading "T_DESPESA_90DIAS_S.txt" file (outgoing 90 days (type 6) record from POF 2008-2009 survey).

In this record we didn't use the variable COD_IMPUT_QUANT (CÓDIGO DE IMPUTAÇÃO - QUANTIDADE), because the label of de codes are to much extensive, so in order not to change the meaning of the labels adapting in the rotulo colummn, we excluded.

Arguments

encoding

UTF-8

format

This dictionary is a data frame with one line for each survey categorical variable, and it has 3 columms, with important information of each categorical variable. lll{ cod character Variable code valor numeric Levels of the categorical variable rotulo numeric Labels of the categorical variable }

source

The dictionaries were made based on the documentation of the PNAD survey available at http://www.ibge.gov.br.