encoding
UTF-8format
This dictionary is a data frame with one line for each survey categorical variable,
and it has 3 columms, with important information of each categorical variable.
lll{
cod character Variable code
valor numeric Levels of the categorical variable
rotulo numeric Labels of the categorical variable
}source
The dictionaries were made based on the documentation of the
PNAD survey available at http://www.ibge.gov.br.