dicPNAD: Data Dictionaries for PNAD
Description
One data dictionary for people records and one for house records,
for each PNAD of the years 1983, 1988 and from 1993 to 2009.encoding
UTF-8format
Each dictionary is a data frame with one line for each survey variable,
and it has the following columns:
lll{
inicio numeric Position of the value's first character in
the data file
cod character Variable code
tamanho numeric Field size
desc character Short description
}source
PNAD documentation available in the CD's made by IBGE