encoding
UTF-8format
This dictionary is a data frame with one line for each survey variable,
and it has 4 columms, with important information of each variable.
lll{
inicio numeric Position of the value's first character in
the data file
cod character Variable code
tamanho numeric Field size
desc character Short description
}source
The dictionaries were made based on the documentation of the
PNAD survey available at http://www.ibge.gov.br.